"use strict";
const baseUrl = 'http://localhost:8082';

$(document).ready(function () {
    checkAvailability();
});

function getOpenSongList() {
    $.get(`${baseUrl}/presentation/slide/list`, function( data ) {
        initialiseTableAndPopulateData(data);
        updateStatus();
    });
}

function updateStatus(onSuccess = () => { }) {
    $.get(`${baseUrl}/presentation/status`, function( data ) {
        setStatusView(data);
    });
}

function setStatusView(data) {
    const $xml = $(data);
    const itemNumber = $xml.find('slide').attr('itemnumber');
    const mode = $xml.find('screen').attr('mode');
    $('.current').removeClass('current');
    $('#container').find("#slide" + itemNumber).addClass('current');
}

function initialiseTableAndPopulateData(data) {
    const $xml = $(data);    
    const $listCon = $('#container');
    $listCon.empty();
    $listCon.append("<table width='100%' id='table-list'></table>");
    const $table = $('#table-list');
    
    $xml.find('slide').each(function () {
        let $row = createListItem(this);
        $table.append($row);
    });
}

function createListItem(slide) {
    const identifier = $(slide).attr('identifier');
    const name = $(slide).attr('name');
    const type = $(slide).attr('type');
    
    let $item = $('<tr></tr>');
    
    $.get(`${baseUrl}/presentation/slide/${identifier}`, function( data ) {
        const $xml = $(data);
        const txt = $xml.find('response').find('slides').find('slide').children('body').text();
        $(`#${identifier}`).text(txt);
    });
    
    $item.attr("id", `slide${identifier}`);
    $item.attr("onclick", `navigateToSlide(${identifier})`);
    $item.addClass(type);
    $item.append(`<td class='song-identifier'>${identifier}</td>`);
    $item.append(`<td class='song-text' id='${identifier}'></td>`);
    $item.append(`<td class='song-name'>${name}</td>`);
    
    localStorage.setItem('opensong-last-identifier', identifier);
    
    return $item;
}

function navigateToSlide(identifier) {
    changeSlideByIdentifier(identifier);
    $.post(`${baseUrl}/presentation/slide/${identifier}`);
}

function changeSlideByIdentifier(identifier) {
    const $moved = $(`#slide${identifier}`);
    $('.current').removeClass('current');
    $('#container').find("#slide" + identifier).addClass('current');
    localStorage.setItem('opensong-identifier', identifier);
}

function checkAvailability(){
    $.get(`${baseUrl}/presentation/slide/1`).done(function () {
        getOpenSongList();
    }).fail(function () {
        setTimeout(checkAvailability, 300);
    });
}